@@ -2,7 +2,7 @@ import asyncio
 from abc import abstractmethod, ABC
 from typing import Union, Type, TypeVar, Iterator, Optional, List, Generic, TYPE_CHECKING
 
-from sqlalchemy import and_, select, Table, exists, MetaData
+from sqlalchemy import and_, select, Table, exists, MetaData, func
 
 from fox_orm import FoxOrm
 from fox_orm.exceptions import NotFetchedException, OrmException
@@ -19,7 +19,7 @@ class HashList(List[MODEL]):
     map: dict
 
     def __init__(self, items: Optional[List[MODEL]] = None):  # pylint: disable=unsubscriptable-object
-        self.map = dict()
+        self.map = {}
         if items is not None:
             super().__init__(items)
             for i, x in enumerate(items):
@@ -73,7 +73,7 @@ class _GenericIterableRelation(ABC):
 
     def __init__(self):
         self._objects = HashList()
-        self.__modified__ = dict()
+        self.__modified__ = {}
         self._fetched = False
         self._initialized = False
 
@@ -98,6 +98,10 @@ class _GenericIterableRelation(ABC):
     async def save(self) -> None:
         ...
 
+    @abstractmethod
+    async def count(self) -> int:
+        ...
+
     async def fetch(self) -> None:
         self._raise_if_not_initialized()
         self._model.ensure_id()
@@ -219,6 +223,13 @@ class ManyToMany(Generic[MODEL], _GenericIterableRelation):
             getattr(self._via.c, self._this_id) == self._model.pkey_value
         ))]
 
+    async def count(self) -> int:
+        return await FoxOrm.db.fetch_val(
+            select([func.count()]).select_from(self._via).where(
+                getattr(self._via.c, self._this_id) == self._model.pkey_value
+            )
+        )
+
     async def save(self) -> None:
         self._model.ensure_id()
         self._raise_if_not_initialized()
@@ -236,7 +247,7 @@ class ManyToMany(Generic[MODEL], _GenericIterableRelation):
                     getattr(self._via.c, self._other_id) == k
                 ))))
         await asyncio.gather(*queries)
-        self.__modified__ = dict()
+        self.__modified__ = {}
 
 
 class OneToMany(Generic[MODEL], _GenericIterableRelation):
@@ -273,10 +284,18 @@ class OneToMany(Generic[MODEL], _GenericIterableRelation):
         return self.to
 
     async def fetch_ids(self) -> List[int]:
+        self._raise_if_not_initialized()
         return [x[self.to.__pkey_name__] for x in await FoxOrm.db.fetch_all(select([self.to.pkey_column]).where(
             getattr(self.to.c, self.key) == self._model.pkey_value
         ))]
 
+    async def count(self) -> int:
+        return await FoxOrm.db.fetch_val(
+            select([func.count()]).select_from(self.to.__table__).where(
+                getattr(self.to.c, self.key) == self._model.pkey_value
+            )
+        )
+
     async def save(self) -> None:
         self._model.ensure_id()
         queries = []
@@ -295,7 +314,7 @@ class OneToMany(Generic[MODEL], _GenericIterableRelation):
                     self.key: None
                 }))
         await asyncio.gather(*queries)
-        self.__modified__ = dict()
+        self.__modified__ = {}
 
 
 __all__ = ['ManyToMany', 'OneToMany']
